@@ -32,7 +32,6 @@
 #include "gupnp-didl-lite-object.h"
 #include "gupnp-didl-lite-object-private.h"
 #include "gupnp-didl-lite-descriptor-private.h"
-#include "gupnp-dlna-private.h"
 
 G_DEFINE_TYPE (GUPnPDIDLLiteWriter,
                gupnp_didl_lite_writer,
@@ -44,6 +43,7 @@ struct _GUPnPDIDLLiteWriterPrivate {
 
         xmlNs       *upnp_ns;
         xmlNs       *dc_ns;
+        xmlNs       *dlna_ns;
 
         char        *language;
 };
@@ -135,6 +135,8 @@ is_standard_prop (const char *name,
                 strcmp (name, "title") == 0) ||
                (g_strcmp0 (namespace, "upnp") == 0 &&
                 strcmp (name, "class") == 0) ||
+               (g_strcmp0 (parent_name, "albumArtURI") == 0 &&
+                strcmp (name, "profileID") == 0) ||
                (g_strcmp0 (parent_name, "res") == 0 &&
                 strcmp (name, "protocolInfo") == 0);
 }
@@ -184,7 +186,9 @@ filter_node (xmlNode             *node,
                 if (child->ns != NULL)
                         ns = (const char *) child->ns->prefix;
 
-                if (!is_standard_prop ((const char *) child->name, ns, NULL) &&
+                if (!is_standard_prop ((const char *) child->name,
+                                       ns,
+                                       (const char *)  node->name) &&
                     is_node_forbidden (child, allowed, ns))
                         forbidden = g_list_append (forbidden, child);
         }
@@ -288,6 +292,11 @@ gupnp_didl_lite_writer_constructed (GObject *object)
                                   "urn:schemas-upnp-org:metadata-1-0/upnp/",
                                   (unsigned char *)
                                   GUPNP_DIDL_LITE_WRITER_NAMESPACE_UPNP);
+        priv->dlna_ns = xmlNewNs (priv->xml_node,
+                                  (unsigned char *)
+                                  "urn:schemas-dlna-org:metadata-2-0/",
+                                  (unsigned char *)
+                                  GUPNP_DIDL_LITE_WRITER_NAMESPACE_DLNA);
         xmlNewNs (priv->xml_node,
                   (unsigned char *)
                   "urn:schemas-upnp-org:metadata-1-0/DIDL-Lite/",
@@ -426,7 +435,8 @@ gupnp_didl_lite_writer_add_item (GUPnPDIDLLiteWriter *writer)
         object = gupnp_didl_lite_object_new_from_xml (item_node,
                                                       writer->priv->xml_doc,
                                                       writer->priv->upnp_ns,
-                                                      writer->priv->dc_ns);
+                                                      writer->priv->dc_ns,
+                                                      writer->priv->dlna_ns);
         return GUPNP_DIDL_LITE_ITEM (object);
 }
 
@@ -454,7 +464,8 @@ gupnp_didl_lite_writer_add_container (GUPnPDIDLLiteWriter *writer)
         object = gupnp_didl_lite_object_new_from_xml (container_node,
                                                       writer->priv->xml_doc,
                                                       writer->priv->upnp_ns,
-                                                      writer->priv->dc_ns);
+                                                      writer->priv->dc_ns,
+                                                      writer->priv->dlna_ns);
         return GUPNP_DIDL_LITE_CONTAINER (object);
 }
 
