@@ -136,7 +136,7 @@ parse_additional_info (const char        *additional_info,
 
                         gupnp_protocol_info_set_dlna_operation
                                                         (info,
-                                                         strtol (p, NULL, 16));
+                                                         strtoul (p, NULL, 16));
 
                         continue;
                 }
@@ -150,7 +150,7 @@ parse_additional_info (const char        *additional_info,
                         p[8] = '\0';
                         gupnp_protocol_info_set_dlna_flags
                                                         (info,
-                                                         strtol (p, NULL, 16));
+                                                         strtoul (p, NULL, 16));
 
                         continue;
                 }
@@ -194,7 +194,16 @@ is_content_format_compat (GUPnPProtocolInfo *info1,
 
         if (mime_type1 [0] != '*' &&
             mime_type2 [0] != '*' &&
-            g_ascii_strcasecmp (mime_type1, mime_type2) != 0)
+            g_ascii_strcasecmp (mime_type1, mime_type2) != 0 &&
+            /* Handle special case for LPCM: It is the only content type that
+             * make use of mime-type parameters that we know of.
+             *
+             * Example: audio/L16;rate=44100;channels=2
+             */
+            !((g_ascii_strcasecmp (mime_type1, "audio/L16") == 0 &&
+               g_ascii_strncasecmp (mime_type2, "audio/L16", 9) == 0) ||
+              (g_ascii_strcasecmp (mime_type2, "audio/L16") == 0 &&
+               g_ascii_strncasecmp (mime_type1, "audio/L16", 9) == 0)))
                 return FALSE;
         else
                 return TRUE;
@@ -227,27 +236,27 @@ add_dlna_info (GString           *str,
         const char *dlna_profile;
         const char **speeds;
         GUPnPDLNAConversion conversion;
+        GUPnPDLNAOperation operation;
+        GUPnPDLNAFlags flags;
 
         dlna_profile = gupnp_protocol_info_get_dlna_profile (info);
         if (dlna_profile == NULL) {
                 g_string_append_printf (str, ":*");
-
                 return;
         }
 
         g_string_append_printf (str, ":DLNA.ORG_PN=%s", dlna_profile);
 
-        /* the OP parameter is only allowed for the "http-get"
-         * and "rtsp-rtp-udp" protocols
-         */
-        if (strcmp (gupnp_protocol_info_get_protocol (info),
-                    "http-get") == 0 ||
-            strcmp (gupnp_protocol_info_get_protocol (info),
-                    "rtsp-rtp-udp") == 0)
-                g_string_append_printf
-                        (str,
-                         ";DLNA.ORG_OP=%.2x",
-                         gupnp_protocol_info_get_dlna_operation (info));
+        operation = gupnp_protocol_info_get_dlna_operation (info);
+        if (operation != GUPNP_DLNA_OPERATION_NONE &&
+            /* the OP parameter is only allowed for the "http-get"
+             * and "rtsp-rtp-udp" protocols
+             */
+            (strcmp (gupnp_protocol_info_get_protocol (info),
+                     "http-get") == 0 ||
+             strcmp (gupnp_protocol_info_get_protocol (info),
+                     "rtsp-rtp-udp") == 0))
+                g_string_append_printf (str, ";DLNA.ORG_OP=%.2x", operation);
 
         /* Specify PS parameter if list of play speeds is provided */
         speeds = gupnp_protocol_info_get_play_speeds (info);
@@ -269,12 +278,15 @@ add_dlna_info (GString           *str,
         if (conversion != GUPNP_DLNA_CONVERSION_NONE)
                 g_string_append_printf (str, ";DLNA.ORG_CI=%d", conversion);
 
-        g_string_append_printf (str,
-                                ";DLNA.ORG_FLAGS=%.8x",
-                                gupnp_protocol_info_get_dlna_flags (info));
-        /*  append 24 reserved hex-digits */
-        g_string_append_printf (str,
-                                "0000" "0000" "0000" "0000" "0000" "0000");
+        flags = gupnp_protocol_info_get_dlna_flags (info);
+        /* Omit the FLAGS parameter if no flags set */
+        if (flags != GUPNP_DLNA_FLAGS_NONE) {
+                g_string_append_printf (str, ";DLNA.ORG_FLAGS=%.8x", flags);
+                /*  append 24 reserved hex-digits */
+                g_string_append_printf (str,
+                                        "0000" "0000" "0000"
+                                        "0000" "0000" "0000");
+        }
 }
 
 static void
@@ -287,7 +299,7 @@ gupnp_protocol_info_init (GUPnPProtocolInfo *info)
 
         info->priv->dlna_conversion = GUPNP_DLNA_CONVERSION_NONE;
         info->priv->dlna_operation  = GUPNP_DLNA_OPERATION_NONE;
-        info->priv->dlna_flags      = GUPNP_DLNA_FLAGS_DLNA_V15;
+        info->priv->dlna_flags      = GUPNP_DLNA_FLAGS_NONE;
 }
 
 static void
@@ -569,7 +581,7 @@ gupnp_protocol_info_class_init (GUPnPProtocolInfoClass *klass)
                                      "DLNAFlags",
                                      "Various generic DLNA flags.",
                                      GUPNP_TYPE_DLNA_FLAGS,
-                                     GUPNP_DLNA_FLAGS_DLNA_V15,
+                                     GUPNP_DLNA_FLAGS_NONE,
                                      G_PARAM_READWRITE |
                                      G_PARAM_STATIC_NAME |
                                      G_PARAM_STATIC_NICK |
@@ -807,7 +819,7 @@ GUPnPDLNAFlags
 gupnp_protocol_info_get_dlna_flags (GUPnPProtocolInfo *info)
 {
         g_return_val_if_fail (GUPNP_IS_PROTOCOL_INFO (info),
-                              GUPNP_DLNA_FLAGS_DLNA_V15);
+                              GUPNP_DLNA_FLAGS_NONE);
 
         return info->priv->dlna_flags;
 }
@@ -973,7 +985,7 @@ gupnp_protocol_info_set_dlna_operation (GUPnPProtocolInfo *info,
  **/
 void
 gupnp_protocol_info_set_dlna_flags (GUPnPProtocolInfo  *info,
-                                         GUPnPDLNAFlags flags)
+                                    GUPnPDLNAFlags      flags)
 {
         g_return_if_fail (GUPNP_IS_PROTOCOL_INFO (info));
 
@@ -984,8 +996,8 @@ gupnp_protocol_info_set_dlna_flags (GUPnPProtocolInfo  *info,
 
 /**
  * gupnp_protocol_info_is_compatible
- * @info: The #GUPnPProtocolInfo
- * @protocol_info: The protocolInfo string
+ * @info1: The first #GUPnPProtocolInfo
+ * @info2: The second #GUPnPProtocolInfo
  *
  * Checks if the given protocolInfo string is compatible with @info.
  *
